==> wpgtk-5.0.3.tar.gz: wpgtk-5.0.3/README.md <==

# wpgtk

![PyPI](https://img.shields.io/pypi/v/wpgtk.svg?style=flat-square)
![license](https://img.shields.io/badge/license-GPLv2-green.svg?style=flat-square)


`wpgtk` uses [pywal](https://github.com/dylanaraps/pywal) as it's colorscheme generator, but builds upon it with a UI and other features, such as the abilty to mix and edit the colorschemes generated and save them with their respective wallpapers, having light and dark themes, hackable and fast GTK+ theme made specifically for `wpgtk` and custom keywords and values to replace in templates.

For those who are not into automatic generated colorschemes, you can now also import colorschemes
in JSON format, you can upload and download themes from the [wpgtk-colorschemes](https://github.com/deviantfero/wpgtk-colorschemes) repository.

In short, `wpgtk` is a colorscheme/wallpaper manager with a template system attached which let's you create templates from any textfile and will replace keywords on it on the fly, allowing for great styling and theming possibilities.

- **Demos:**
[[GUI](https://gfycat.com/RigidAnxiousElk)]
[[CLI](https://gfycat.com/NeighboringSarcasticEquine)]
[[Templates](https://gfycat.com/VacantHeavyAmericansaddlebred)]

- **Wiki:**
[[Installation](https://github.com/deviantfero/wpgtk/wiki/Installation)]
[[Colorschemes](https://github.com/deviantfero/wpgtk/wiki/Colorschemes)]
[[Configuration](https://github.com/deviantfero/wpgtk/wiki/Configuration)]
[[Custom Keywords](https://github.com/deviantfero/wpgtk/wiki/Custom-Keywords)]
[[Templates](https://github.com/deviantfero/wpgtk/wiki/Templates)]

- **Tutorials:**
[[Installation](https://www.youtube.com/watch?v=jmY5NEPI4RM)]
[[Advanced Features](https://www.youtube.com/watch?v=QXpMMP8fT0o)]
[[Command Line](https://www.youtube.com/watch?v=yjNipQZpOUc)]
[[Import/export Colorschemes](https://www.youtube.com/watch?v=P3D0jtG6G2s)]



## Gallery
<p align="center">
  <img src="https://i.imgur.com/UvVonun.gif"/>
</p>

![i3_setup](https://i.imgur.com/ybqWBO6.png)

![light_theme](https://i.imgur.com/Pc2zRej.png)

![openbox setup](http://i.imgur.com/2cquXzm.png)

# License

This project is licensed under the GPLv2 License - see the [LICENSE](LICENSE) file for details

==> wpgtk-5.5.0.tar.gz: wpgtk-5.5.0/README.md <==

# wpgtk

![PyPI](https://img.shields.io/pypi/v/wpgtk.svg?style=flat-square)
![license](https://img.shields.io/badge/license-GPLv2-green.svg?style=flat-square)


`wpgtk` uses [pywal](https://github.com/dylanaraps/pywal) as it's colorscheme generator, but builds upon it with a UI and other features, such as the abilty to mix and edit the colorschemes generated and save them with their respective wallpapers, having light and dark themes, hackable and fast GTK+ theme made specifically for `wpgtk` and custom keywords and values to replace in templates.

For those who are not into automatic generated colorschemes, you can now also import colorschemes
in JSON format, you can upload and download themes from the [wpgtk-colorschemes](https://github.com/deviantfero/wpgtk-colorschemes) repository, wpgtk is also compatible with all of `pywal`'s included themes, 
that's more than 250 themes from the get go.

In short, `wpgtk` is a colorscheme/wallpaper manager with a template system attached which let's you create templates from any textfile and will replace keywords on it on the fly, allowing for great styling and theming possibilities.

## Usage

- **Demos:**
[[GUI](https://gfycat.com/RigidAnxiousElk)]
[[CLI](https://gfycat.com/NeighboringSarcasticEquine)]
[[Templates](https://gfycat.com/VacantHeavyAmericansaddlebred)]

- **Wiki:**
[[Installation](https://github.com/deviantfero/wpgtk/wiki/Installation)]
[[Colorschemes](https://github.com/deviantfero/wpgtk/wiki/Colorschemes)]
[[Configuration](https://github.com/deviantfero/wpgtk/wiki/Configuration)]
[[Custom Keywords](https://github.com/deviantfero/wpgtk/wiki/Custom-Keywords)]
[[Templates](https://github.com/deviantfero/wpgtk/wiki/Templates)]

- **Tutorials:**
[[Installation](https://www.youtube.com/watch?v=jmY5NEPI4RM)]
[[Advanced Features](https://www.youtube.com/watch?v=QXpMMP8fT0o)]
[[Command Line](https://www.youtube.com/watch?v=yjNipQZpOUc)]
[[Import/export Colorschemes](https://www.youtube.com/watch?v=P3D0jtG6G2s)]

- **Other Repos:**
[[wpgtk.vim](https://github.com/deviantfero/wpgtk.vim)]
[[wpgtk-templates](https://github.com/deviantfero/wpgtk-templates)]
[[wpgtk-colorschemes](https://github.com/deviantfero/wpgtk-colorschemes)]



## Gallery
<p align="center">
  <img src="https://i.imgur.com/UvVonun.gif"/>
</p>

<div style="display: flex; width: 100%">
  <img style="width: 50%;" src="https://i.imgur.com/jt9LlFE.png"/>
  <img style="width: 50%;" src="https://i.imgur.com/GQ8vESj.png"/>
</div>

# License

This project is licensed under the GPLv2 License - see the [LICENSE](LICENSE) file for details
